@@ -59,7 +59,7 @@ impl<'txin> Interpreter<'txin> {
         witness: &'txin Witness,
         age: u32,
         height: u32,
-        txtemplate: sha256::Hash
+        txtemplate: sha256::Hash,
     ) -> Result<Self, Error> {
         let (inner, stack, script_code) = inner::from_txdata(spk, script_sig, witness)?;
         Ok(Interpreter {
@@ -309,8 +309,8 @@ pub enum SatisfiedConstraint<'intp, 'txin> {
     /// Check Template Verify Covenant
     TxTemplate {
         /// The hash value of the transaction
-        hash: &'intp sha256::Hash
-    }
+        hash: &'intp sha256::Hash,
+    },
 }
 
 ///This is used by the interpreter to know which evaluation state a AstemElem is.
@@ -742,14 +742,14 @@ where
                         }
                     }
                 }
-                Terminal::TxTemplate(h) => {
+                Terminal::TxTemplate(ref h) => {
                     debug_assert_eq!(node_state.n_evaluated, 0);
                     debug_assert_eq!(node_state.n_satisfied, 0);
-                    let res = self.stack.evaluate_txtemplate(&self.txtemplate);
+                    let res = self.stack.evaluate_txtemplate(&h, &self.txtemplate);
                     if res.is_some() {
                         return res;
                     }
-                },
+                }
                 //All other match patterns should not be reached in any valid
                 //type checked Miniscript
                 _ => return Some(Err(Error::CouldNotEvaluate)),
